@@ -19,8 +19,12 @@ import (
 	routeclient "github.com/openshift/client-go/route/clientset/versioned"
 	routeinformer "github.com/openshift/client-go/route/informers/externalversions"
 	"github.com/openshift/library-go/pkg/controller/controllercmd"
+	"github.com/openshift/library-go/pkg/operator/loglevel"
+	"github.com/openshift/library-go/pkg/operator/management"
 	"github.com/openshift/library-go/pkg/operator/resourcesynccontroller"
+	"github.com/openshift/library-go/pkg/operator/staleconditions"
 	"github.com/openshift/library-go/pkg/operator/status"
+	"github.com/openshift/library-go/pkg/operator/unsupportedconfigoverridescontroller"
 	"github.com/openshift/library-go/pkg/operator/v1helpers"
 )
 
@@ -153,6 +157,23 @@ func RunOperator(ctx *controllercmd.ControllerContext) error {
 		ctx.EventRecorder,
 	)
 
+	staleConditions := staleconditions.NewRemoveStaleConditions(
+		[]string{
+			// in 4.1.0 this was accidentally in the list.  This can be removed in 4.3.
+			"Degraded",
+		},
+		operatorClient,
+		ctx.EventRecorder,
+	)
+
+	configOverridesController := unsupportedconfigoverridescontroller.NewUnsupportedConfigOverridesController(operatorClient, ctx.EventRecorder)
+	logLevelController := loglevel.NewClusterOperatorLoggingController(operatorClient, ctx.EventRecorder)
+	// TODO remove this controller once we support Removed
+	managementStateController := management.NewOperatorManagementStateController(clusterOperatorName, operatorClient, ctx.EventRecorder)
+	management.SetOperatorNotRemovable()
+	// TODO move to config observers
+	// configobserver.NewConfigObserver(...)
+
 	for _, informer := range []interface {
 		Start(stopCh <-chan struct{})
 	}{
@@ -165,9 +186,20 @@ func RunOperator(ctx *controllercmd.ControllerContext) error {
 		informer.Start(ctx.Done())
 	}
 
+	for _, controller := range []interface {
+		Run(workers int, stopCh <-chan struct{})
+	}{
+		resourceSyncer,
+		clusterOperatorStatus,
+		configOverridesController,
+		logLevelController,
+		managementStateController,
+	} {
+		go controller.Run(1, ctx.Done())
+	}
+
 	go operator.Run(ctx.Done())
-	go resourceSyncer.Run(1, ctx.Done())
-	go clusterOperatorStatus.Run(1, ctx.Done())
+	go staleConditions.Run(1, ctx.Done())
 
 	<-ctx.Done()
 
